@@ -16,15 +16,9 @@
 
 You'll typically use these to get started with the API:
 
->>> from google.cloud import storage
->>> client = storage.Client()
->>> bucket = client.get_bucket('bucket-id-here')
->>> # Then do other things...
->>> blob = bucket.get_blob('/remote/path/to/file.txt')
->>> print(blob.download_as_string())
->>> blob.upload_from_string('New contents!')
->>> blob2 = bucket.blob('/remote/path/storage.txt')
->>> blob2.upload_from_filename(filename='/local/path.txt')
+.. literalinclude:: storage_snippets.py
+    :start-after: [START storage_get_started]
+    :end-before: [END storage_get_started]
 
 The main concepts with this API are:
 
@@ -36,6 +30,10 @@ The main concepts with this API are:
   machine).
 """
 
+
+from pkg_resources import get_distribution
+__version__ = get_distribution('google-cloud-storage').version
+
 from google.cloud.storage.batch import Batch
 from google.cloud.storage.blob import Blob
 from google.cloud.storage.bucket import Bucket
