@@ -28,7 +28,7 @@ class _PropertyMixin(object):
       - client
       - path
 
-    :type name: string
+    :type name: str
     :param name: The name of the object.
     """
 
@@ -74,7 +74,7 @@ class _PropertyMixin(object):
         # Pass only '?projection=noAcl' here because 'acl' and related
         # are handled via custom endpoints.
         query_params = {'projection': 'noAcl'}
-        api_response = client.connection.api_request(
+        api_response = client._connection.api_request(
             method='GET', path=self.path, query_params=query_params,
             _target_object=self)
         self._set_properties(api_response)
@@ -88,7 +88,7 @@ class _PropertyMixin(object):
         It **will not** reload the properties from the server. The behavior is
         local only and syncing occurs via :meth:`patch`.
 
-        :type name: string
+        :type name: str
         :param name: The field name to update.
 
         :type value: object
@@ -122,7 +122,7 @@ class _PropertyMixin(object):
         # to work properly w/ 'noAcl'.
         update_properties = {key: self._properties[key]
                              for key in self._changes}
-        api_response = client.connection.api_request(
+        api_response = client._connection.api_request(
             method='PATCH', path=self.path, data=update_properties,
             query_params={'projection': 'full'}, _target_object=self)
         self._set_properties(api_response)
@@ -151,7 +151,7 @@ def _write_buffer_to_hash(buffer_object, hash_obj, digest_block_size=8192):
     :type hash_obj: object that implements update
     :param hash_obj: A hash object (MD5 or CRC32-C).
 
-    :type digest_block_size: integer
+    :type digest_block_size: int
     :param digest_block_size: The block size to write to the hash.
                               Defaults to 8192.
     """
